Installation — django-qanda 0.1.0 documentation

### Navigation

- index
- next |
- previous |
- django-qanda 0.1.0 documentation »

# Installation

This part of the documentation covers the installation of Qanda.

## Requirements

Qanda currently runs on Django 1.6 or greater, Python 2.7 or greater.

## Distribute & Pip

Installing Qanda is simple with pip, just run this in your terminal:

    $ pip install django-qanda

or, with easy_install:

    $ easy_install django-qanda

Using pip is the recommended method.

## Get the code

Qanda is actively developed on Bitbucket, where the code is always available.

You can either clone the repository:

    $ hg clone https://bitbucket.org/mhurt/django-qanda

or download the tar-ball or zip-ball of your choice.

Once you have a copy of the source, you can install it into your site packages easily:

    $ python setup.py install

## Configuring your project

In your Django project’s settings, add Qanda to your `INSTALLED_APPS` setting:

    INSTALLED_APPS = {
      ...
      'qanda'
    }

Include the qanda URLconf in your project urls.py like this:

    url(r'^faq/', include('qanda.urls'))

In Django 1.7 run `python manage.py migrate qanda`. Otherwise, just run `python manage.py syncdb`.

### Navigation

- index
- next |
- previous |
- django-qanda 0.1.0 documentation »